@@ -1,7 +1,7 @@
-context("OptimizerCmaes")
-
 test_that("OptimizerCmaes", {
-  z = test_optimizer("cmaes", par = 1, n_dim = 1, term_evals = 2L)
+  skip_if_not_installed("adagio")
+
+  z = test_optimizer("cmaes", n_dim = 1, term_evals = 2L)
   expect_class(z$optimizer, "OptimizerCmaes")
   expect_output(print(z$optimizer), "OptimizerCmaes")
 
