@@ -1,6 +1,6 @@
-context("OptimizerGenSA")
-
 test_that("OptimizerGenSA", {
+  skip_if_not_installed("GenSA")
+
   z = test_optimizer("gensa", n_dim = 1, term_evals = 10L)
   expect_class(z$optimizer, "OptimizerGenSA")
   expect_output(print(z$optimizer), "OptimizerGenSA")
