@@ -7,3 +7,9 @@ test_that("TerminatorNone works", {
   a = random_search(inst, batch_size = 1L)
   expect_equal(a$n_evals, 10L, info = mode)
 })
+
+test_that("TerminatorNone works with empty archive" ,{
+  terminator = TerminatorNone$new()
+  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl()))
+  expect_false(terminator$is_terminated(archive))
+})
\ No newline at end of file
